@@ -98,8 +98,8 @@ void WeatherLib::slotCopyDone(KIO::Job* job)
 	{
 		kdDebug(12006) << "Error code: " << job->error() << endl;
 		//job->showErrorDialog(0L);
-		if(job->error() == KIO::ERR_COULD_NOT_CONNECT ||
-			job->error() == KIO::ERR_UNKNOWN_HOST)
+		if ((job->error() == KIO::ERR_COULD_NOT_CONNECT || job->error() == KIO::ERR_UNKNOWN_HOST)
+		    && !hostDown)
 		{
 			hostDown= true;
 			// should not bother after this point
@@ -189,9 +189,9 @@ void WeatherLib::slotCopyDone(KIO::Job* job)
 	}
 }
 
-void WeatherLib::getData(Data *d)
+void WeatherLib::getData(Data *d, bool force /* try even if host was down last time*/)
 {
-	if(!d->downloading && !hostDown)
+	if(!d->downloading && (force || !hostDown) )
 	{
 		d->downloading = true;
 		d->updated = false;
@@ -319,8 +319,6 @@ bool WeatherLib::stationNeedsMaintenance(const QString &stationID)
 
 void WeatherLib::update(const QString &stationID)
 {
-	// refresh hostdown just to see
-	hostDown = false;
 	// Only grab new data if its more than 50 minutes old
 	Data *d = findData(stationID);
 
@@ -329,7 +327,7 @@ void WeatherLib::update(const QString &stationID)
 	kdDebug (12006) << "Current Time: " << KGlobal::locale()->formatDateTime(timeout, false, false) <<
 			" Update at: " << KGlobal::locale()->formatDateTime(d->age, false, false) << endl;
 	if( timeout >= d->age || !d->updated)
-		getData(d);
+		getData(d, true /* try even if host was down last time */);
 	else
 		emit fileUpdate(d->wi.reportLocation);
 }
@@ -345,8 +343,8 @@ QStringList WeatherLib::stations()
 
 void WeatherLib::forceUpdate(const QString &stationID)
 {
+	hostDown = false; // we want to show error message if host is still down
 	Data *d = findData(stationID);
-
 	getData( d );
 }
 
